==> spectus_tus_uploader-0.0.2.tar.gz: ios/Classes/FileUploadHelper.swift <==
//
//  FileUploadHelper.swift
//  Upload Task
//
//  Created by Akash Patel on 24/09/21.
//

import Foundation
import TUSKit

class FileUploaderHelper: NSObject {
    
    static let shared = FileUploaderHelper()
    var progressHandler : ((_ uploaded : Double, _ remaining : Double) -> Void)?
    var successOrFailureHandler : ((_ errorMessage : String?, _ uploadFileURL : String?)->Void)?
    
    override init() {
    }
    
    func initialiseUploaderWith(_ uploadURL : String) {
        let config = TUSConfig(withUploadURLString: uploadURL, andSessionConfig: URLSessionConfiguration.default)
        TUSClient.setup(with: config)
//        TUSClient.shared.delegate = self
    }
    
    func uploadFileWith(fileURL: URL, fileType: String, authEmail: String, authKey: String, authToken: String, progressHandler : ((_ uploaded : Double, _ remaining : Double)->Void)? = nil, successOrFailureHandler: ((_ errorMessage : String?, _ uploadFileURL : String?)->Void)? = nil) {
        
        DispatchQueue.main.async {
            self.progressHandler = progressHandler
            self.successOrFailureHandler = successOrFailureHandler
            
            let fileID = Int64(Date().timeIntervalSince1970 * 1000).description
            let header : [String : String] = ["X-Auth-Email" : authEmail,
                                              "X-Auth-Key": authKey,
                                              "Authorization": "Bearer \(authToken)"]
            let uploadObject = TUSUpload.init(withId: fileID, andFilePathURL: fileURL, andFileType: fileType)
            TUSClient.shared.delegate = self
            TUSClient.shared.createOrResume(forUpload: uploadObject, withCustomHeaders: header)
            TUSClient.shared.resumeAll()
        }
    }
    
}

extension FileUploaderHelper : TUSDelegate {
    func TUSProgress(bytesUploaded uploaded: Int, bytesRemaining remaining: Int) {
        //print("Uploaded: \(uploaded/1000000) MB\nTotal: \(remaining/1000000) MB")
    }
    
    func TUSProgress(forUpload upload: TUSUpload, bytesUploaded uploaded: Int, bytesRemaining remaining: Int) {
        print("Uploaded: \(uploaded/1000000) MB\nTotal: \(remaining/1000000) MB")
        let uploadedMB = Double(uploaded/1000000).rounded(toPlaces: 2)
        let totalMB = Double(remaining/1000000).rounded(toPlaces: 2)
        self.progressHandler?(uploadedMB, totalMB)
    }
    
    func TUSSuccess(forUpload upload: TUSUpload) {
        self.successOrFailureHandler?(nil, upload.uploadLocationURL?.absoluteString ?? "")
        print("Uploaded Successfully!")
    }
    
    func TUSFailure(forUpload upload: TUSUpload?, withResponse response: TUSResponse?, andError error: Error?) {
        print(error?.localizedDescription ?? "Failed to upload")
        self.successOrFailureHandler?(error?.localizedDescription, nil)
    }
}

extension Double {
    /// Rounds the double to decimal places value
    func rounded(toPlaces places:Int) -> Double {
        let divisor = pow(10.0, Double(places))
        return (self * divisor).rounded() / divisor
    }
}

==> spectus_tus_uploader-0.0.15.tar.gz: ios/Classes/FileUploadHelper.swift <==
//
//  FileUploadHelper.swift
//  Upload Task
//
//  Created by Akash Patel on 24/09/21.
//

import Foundation
import TUSKit

class FileUploaderHelper: NSObject {
    
    static let shared = FileUploaderHelper()
    var progressHandler : ((_ uploaded : Double, _ remaining : Double) -> Void)?
    var successOrFailureHandler : ((_ errorMessage : String?, _ uploadFileURL : String?)->Void)?
    
    override init() {
    }
    
    func initialiseUploaderWith(_ uploadURL : String) {
        let config = TUSConfig(withUploadURLString: uploadURL, andSessionConfig: URLSessionConfiguration.default)
        TUSClient.setup(with: config)
        //        TUSClient.shared.delegate = self
    }
    
    func uploadFileWith(fileURL: URL, fileType: String, authEmail: String, authKey: String, authToken: String, progressHandler : ((_ uploaded : Double, _ remaining : Double)->Void)? = nil, successOrFailureHandler: ((_ errorMessage : String?, _ uploadFileURL : String?)->Void)? = nil) {
        
        DispatchQueue.main.async {
            self.progressHandler = progressHandler
            self.successOrFailureHandler = successOrFailureHandler
            
            let fileID = Int64(Date().timeIntervalSince1970 * 1000).description
            let header : [String : String] = ["X-Auth-Email" : authEmail,
                                              "X-Auth-Key": authKey,
                                              "Authorization": "Bearer \(authToken)"]
            let uploadObject = TUSUpload.init(withId: fileID, andFilePathURL: fileURL, andFileType: fileType)
            TUSClient.shared.delegate = self
            TUSClient.shared.createOrResume(forUpload: uploadObject, withCustomHeaders: header)
            TUSClient.shared.resumeAll()
        }
    }
    
}

extension FileUploaderHelper : TUSDelegate {
    func TUSProgress(bytesUploaded uploaded: Int, bytesRemaining remaining: Int) {
        //print("Uploaded: \(uploaded/1000000) MB\nTotal: \(remaining/1000000) MB")
    }
    
    func TUSProgress(forUpload upload: TUSUpload, bytesUploaded uploaded: Int, bytesRemaining remaining: Int) {
        print("Uploaded: \(uploaded/1000000) MB\nTotal: \(remaining/1000000) MB")
        let uploadedMB = Double(uploaded/1000000).rounded(toPlaces: 2)
        let totalMB = Double(remaining/1000000).rounded(toPlaces: 2)
        self.progressHandler?(uploadedMB, totalMB)
    }
    
    func TUSSuccess(forUpload upload: TUSUpload) {
        if let uploadedMediaPath = upload.uploadLocationURL?.absoluteString {
            let allComponents = uploadedMediaPath.components(separatedBy: "/")
            if let preIndex = allComponents.firstIndex(of: "media") {
                var mediaID = allComponents[preIndex + 1]
                
                if mediaID.contains("?"), let actualID = mediaID.components(separatedBy: "?").first {
                    mediaID = actualID
                }
                
                self.successOrFailureHandler?(nil, mediaID)
                print("Media ID: \(mediaID)")
            }
        } else {
            //Return Empty
            self.successOrFailureHandler?("Could not get media ID", nil)
        }
        print("Uploaded Successfully!")
    }
    
    func TUSFailure(forUpload upload: TUSUpload?, withResponse response: TUSResponse?, andError error: Error?) {
        print(error?.localizedDescription ?? "Failed to upload")
        self.successOrFailureHandler?(error?.localizedDescription, nil)
    }
}

extension Double {
    /// Rounds the double to decimal places value
    func rounded(toPlaces places:Int) -> Double {
        let divisor = pow(10.0, Double(places))
        return (self * divisor).rounded() / divisor
    }
}
